@@ -21,7 +21,7 @@ class RWR(BlackBoxOptimization):
         """
         self.beta = beta
 
-        self._add_save_attr(beta='numpy')
+        self._add_save_attr(beta='primitive')
 
         super().__init__(mdp_info, distribution, policy, features)
 
