@@ -10,10 +10,9 @@ class ExpectedSARSA(TD):
 
     """
     def __init__(self, mdp_info, policy, learning_rate):
-        self.Q = Table(mdp_info.size)
-        self._add_save_attr(Q='pickle')
+        Q = Table(mdp_info.size)
 
-        super().__init__(mdp_info, policy, self.Q, learning_rate)
+        super().__init__(mdp_info, policy, Q, learning_rate)
 
     def _update(self, state, action, reward, next_state, absorbing):
         q_current = self.Q[state, action]
