@@ -29,6 +29,13 @@ try:
 except ImportError:
     pass
 
+try:
+    PyBullet = None
+    from .pybullet import PyBullet
+    __extras__.append('PyBullet')
+except ImportError:
+    pass
+
 from .car_on_hill import CarOnHill
 from .generators.simple_chain import generate_simple_chain
 from .grid_world import GridWorld, GridWorldVanHasselt
